const express = require("express");
const mysql = require("mysql2");
require("dotenv").config();

const app = express();
app.use(express.json());

// mysql connection
const pool = mysql.createPool({
  // host: "corps-mysql-db", -> need this for prod
  host: process.env.DB_HOST,
  user: process.env.DB_USER || "corps_directory_dev",
  database: process.env.DB_NAME || "corps_directory_db",
  password: process.env.DB_PASSWORD || "corps_db_password",
  waitForConnections: true,
  connectionLimit: 10, // Max number of connections in the pool
  queueLimit: 0, // Unlimited queue
});

// Check connection and create the 'people' table on initialization
pool.getConnection((err, connection) => {
  if (err) {
    console.error("Error connecting to MySQL:", err.message);
    return;
  }
  console.log("Connected to MySQL");

  const createTable = `
    CREATE TABLE IF NOT EXISTS people (
      id INT AUTO_INCREMENT PRIMARY KEY,
      first_name VARCHAR(255) NOT NULL,
      last_name VARCHAR(255) NOT NULL
    )
  `;

  connection.query(createTable, (err, result) => {
    if (err) {
      console.error("Error creating table:", err.message);
      connection.release(); // Release the connection back to the pool
      return;
    }

    console.log("Table 'people' exists or was created.");
    connection.release(); // Release the connection back to the pool
  });
});

// POST endpoint to add a new person
app.post("/people", (req, res) => {
  const { first_name, last_name } = req.body;

  if (!first_name || !last_name) {
    return res.status(400).send("First name and last name are required.");
  }

  const insertPersonQuery = `INSERT INTO people (first_name, last_name) VALUES (?, ?)`;

  pool.query(insertPersonQuery, [first_name, last_name], (err, result) => {
    if (err) {
      console.error("Error inserting person:", err.message);
      return res.status(500).send("Error adding person.");
    }
    res.status(201).send(`Person added with ID: ${result.insertId}`);
  });
});

/*
fhsdfhs
*/

// GET endpoint to get all people
app.get("/people", (req, res) => {
  const getAllPeopleQuery = `SELECT * FROM people`;

  pool.query(getAllPeopleQuery, (err, results) => {
    if (err) {
      console.error("Error fetching people:", err.message);
      return res.status(500).send("Error fetching people.");
    }
    res.status(200).json(results);
  });
});

// Basic route to check if server is running
app.get("/", (req, res) => {
  res.send("Hello World!");
});

const port = process.env.PORT || 3000;

app.listen(port, () => {
  console.log(`Server is running on port ${port}`);
});
